@@ -24,7 +24,7 @@ __author__ = 'Costin Stroie'
 __email__ = 'costinstroie@eridu.eu.org'
 __copyright__ = 'Copyright 2010, Costin Stroie'
 __license__ = 'GPLv3'
-__version__ = '0.1.4'
+__version__ = '0.2.1'
 
 
 # Import the required modules
@@ -40,8 +40,15 @@ import os
 from optparse import OptionParser
 
 # Radios name and base urls
-RADIOS = {'sky': ('SKY.FM', 'http://listen.sky.fm/'),
-          'di':  ('Digitally Imported', 'http://listen.di.fm/')}
+RADIOS = {'sky':   ('SKY.FM', 'http://listen.sky.fm/'),
+          'di':    ('Digitally Imported', 'http://listen.di.fm/'),
+          'jazz':  ('Jazz Radio', 'http://listen.jazzradio.com/'),
+          'rock':  ('Rock Radio', 'http://listen.rockradio.com/')}
+
+FORMATS = {'mp3':  'MP3 (96kbps)',
+           'aac':  'AAC (64kbps)',
+           'aac+': 'AAC-HE (40kbps)'}
+
 
 EXTENSIONS = {'m3u': 'm3u',
               'radiotray': 'xml'}
@@ -78,12 +85,14 @@ class ThreadParsePlaylist(threading.Thread):
 def get_stations_list(radio, stream_type, verbose = False):
     """ Get a list with all stations, as a json object """
     radio_name, radio_url = RADIOS[radio]
-    if stream_type == 'aac':
+    if stream_type == 'aac+':
         url = radio_url + 'public1'
+    elif stream_type == 'aac':
+        url = radio_url + 'appleapp'
     else:
         url = radio_url + 'public3'
     if verbose:
-        print 'Loading %s %s stations at %s' % (radio_name, stream_type, url)
+        print 'Loading %s %s stations at %s' % (radio_name, FORMATS[stream_type], url)
     # Return the json object
     return json.load(urllib2.urlopen(url))
 
@@ -177,11 +186,11 @@ def main():
     optparser.add_option('-r', '--radio',
                          dest = 'radio',
                          help = 'the radio source',
-                         choices = ['sky', 'di'])
+                         choices = ['sky', 'di', 'jazz', 'rock'])
     optparser.add_option('-f', '--format',
                          dest = 'format',
                          help = 'format of the stream',
-                         choices = ['mp3', 'aac'])
+                         choices = ['mp3', 'aac', 'aac+'])
     optparser.add_option('-p', '--playlist',
                          dest = 'playlist',
                          help = 'format of the playlist',
@@ -227,8 +236,8 @@ def main():
     if options.output:
         output = options.output
     else:
-        output = '%s-%s.%s' % (options.radio,
-                               options.format,
+        output = '%s - %s.%s' % (RADIOS[options.radio][0],
+                               FORMATS[options.format],
                                EXTENSIONS[options.playlist])
     # Select the playlist format
     if options.playlist == 'm3u':
